@@ -9,5 +9,6 @@ utils::globalVariables(c(".", "Ecological", "Interaction", "Interactive variable
                          "significance", "Variable1 SPD", "Variable2 SPD", "eco",
                          "risk", "n", "lr", "lr_before", "k", "method", "spade_cpsd",
                          "qv_theta", "qv_rid", "su", "v1", "v2", "zone_risk", "PD",
-                         "Variable1 and Variable2 interact PD"))
+                         "Variable1 and Variable2 interact PD", "psd", "spd", "qv_text",
+                         "variable_col", "name", "step", "xend", "y", "yend"))
 
