@@ -10,7 +10,7 @@
 #' https://doi.org/10.1016/j.isprsjprs.2022.01.009
 #'
 #' @param formula A formula of GOZH model.
-#' @param data A data.frame or tibble of observation data.
+#' @param data A data.frame, tibble or sf object of observation data.
 #' @param cores (optional) A positive integer(default is 1). If cores > 1, a 'parallel' package
 #' cluster with that many cores is created and used. You can also supply a cluster object.
 #' @param type (optional) The type of geographical detector,which must be `factor`(default),
@@ -34,6 +34,7 @@
 #'
 gozh = \(formula, data, cores = 1,
          type = "factor",alpha = 0.95,...){
+  if (inherits(data,'sf')) {data = sf::st_drop_geometry(data)}
   if (length(type) == 1){
     res = gozh_detector(formula, data, cores, type, alpha, ...)
   } else {
